@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         JobStatistic.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -28,12 +28,16 @@
 import os
 import os.path
 import re
+import logging
 from UserDict import UserDict
 
 class JobStatistic(UserDict):
    def __init__(self,
                 nCores):
+      self.logger = logging.getLogger(__name__)
+
       UserDict.__init__(self)
+
       self['jobSubmissionMechanism'] = 'Unknown'
       self['remoteJobIdNumber']      = ''
       self['event']                  = ''
@@ -125,7 +129,7 @@ class JobStatistic(UserDict):
             fpTimer.close()
 
             if exitSignal > 0:
-               self['exitCode']    = exitStatus << 8 | exitSignal
+               self['exitCode']    = exitStatus << 7 | exitSignal
             else:
                self['exitCode']    = exitStatus
             self['realTime']       = realTime
