@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         RemoteProbeMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +25,9 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
-from hubzero.submit.LogMessage  import logID as log
+import logging
+
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class RemoteProbeMonitor(MessageCore):
@@ -36,6 +38,8 @@ class RemoteProbeMonitor(MessageCore):
                 fixedBufferSize=128,
                 ignoreProbeSites=[]):
       MessageCore.__init__(self,listenerHost=host,listenerPort=port,repeatDelay=repeatDelay)
+
+      self.logger          = logging.getLogger(__name__)
       self.fixedBufferSize = fixedBufferSize
       self.results = {}
       self.ignoreProbeSites = []
@@ -56,7 +60,7 @@ class RemoteProbeMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: Q(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: Q(%d):%s" % (nTry,response)))
 
       if response != "":
          timeEvaluated,status,waitRank = response.split()
@@ -92,7 +96,23 @@ class RemoteProbeMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: U(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: U(%d):%s" % (nTry,response)))
+
+
+   def deleteProbeSite(self,
+                       siteName):
+      queryMessage = "D:" + siteName
+      nTry,response = self.requestMessageResponse(queryMessage,
+                                                  self.fixedBufferSize,
+                                                  self.fixedBufferSize,
+                                                  True)
+
+      if nTry > 1:
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: Q(%d):%s" % (nTry,response)))
+
+      siteDeleted = bool(response)
+
+      return(siteDeleted)
 
 
    def reportProbeSiteStatus(self):
@@ -105,7 +125,7 @@ class RemoteProbeMonitor(MessageCore):
                                                         True)
 
       if nTry > 1:
-         log("confirmation: R(%d): %d" % (nTry,len(report)))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: R(%d): %d" % (nTry,len(report))))
 
       return(report)
 
