@@ -1,10 +1,10 @@
 # @package      hubzero-submit-common
 # @file         RemoteTunnelMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +25,9 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
-from hubzero.submit.LogMessage  import logID as log
+import logging
+
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class RemoteTunnelMonitor(MessageCore):
@@ -35,6 +37,8 @@ class RemoteTunnelMonitor(MessageCore):
                 repeatDelay=5,
                 fixedBufferSize=64):
       MessageCore.__init__(self,listenerHost=host,listenerPort=port,repeatDelay=repeatDelay)
+
+      self.logger          = logging.getLogger(__name__)
       self.fixedBufferSize = fixedBufferSize
 
 
@@ -50,7 +54,7 @@ class RemoteTunnelMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: A(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: A(%d):%s" % (nTry,response)))
 
       if response != "":
          address,port = response.split()
@@ -69,7 +73,7 @@ class RemoteTunnelMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: I(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: I(%d):%s" % (nTry,response)))
 
       if response != "":
          useCount = response.strip()
@@ -88,7 +92,7 @@ class RemoteTunnelMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: D(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: D(%d):%s" % (nTry,response)))
 
       if response != "":
          useCount = response.strip()
@@ -107,7 +111,7 @@ class RemoteTunnelMonitor(MessageCore):
                                                   True)
 
       if nTry > 1:
-         log("confirmation: T(%d):%s" % (nTry,response))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: T(%d):%s" % (nTry,response)))
 
       if response != "":
          useCount = response.strip()
@@ -126,7 +130,7 @@ class RemoteTunnelMonitor(MessageCore):
                                                         True)
 
       if nTry > 1:
-         log("confirmation: R(%d): %d" % (nTry,len(report)))
+         self.logger.log(logging.WARNING,getLogMessage("confirmation: R(%d): %d" % (nTry,len(report))))
 
       return(report.strip())
 
